Index: src/x64/lithium-codegen-x64.cc |
diff --git a/src/x64/lithium-codegen-x64.cc b/src/x64/lithium-codegen-x64.cc |
index 12d912c396f1a146b1326628f20dbbd91d90681b..0bf218d864ff2872d368c865b8a30e2c4eecd329 100644 |
--- a/src/x64/lithium-codegen-x64.cc |
+++ b/src/x64/lithium-codegen-x64.cc |
@@ -1529,7 +1529,7 @@ void LCodeGen::CallKnownFunction(Handle<JSFunction> function, |
__ movq(rsi, FieldOperand(rdi, JSFunction::kContextOffset)); |
} |
// Set eax to arguments count if adaption is not needed. Assumes that eax |
// is available to write to at this point. |
if (!function->NeedsArgumentsAdaption()) { |
__ Set(rax, arity); |
@@ -1554,7 +1554,7 @@ void LCodeGen::CallKnownFunction(Handle<JSFunction> function, |
void LCodeGen::DoCallConstantFunction(LCallConstantFunction* instr) { |
- ASSERT(ToRegister(instr->result()).is(eax)); |
+ ASSERT(ToRegister(instr->result()).is(rax)); |
__ Move(rdi, instr->function()); |
CallKnownFunction(instr->function(), instr->arity(), instr); |
} |
@@ -1529,7 +1529,7 @@ void LCodeGen::CallKnownFunction(Handle<JSFunction> function, |
__ movq(rsi, FieldOperand(rdi, JSFunction::kContextOffset)); |
} |
- // Set eax to arguments count if adaption is not needed. Assumes that eax |
+ // Set rax to arguments count if adaption is not needed. Assumes that rax |
// is available to write to at this point. |
if (!function->NeedsArgumentsAdaption()) { |